@@ -30,7 +30,7 @@ our @EXPORT_OK= qw( is_port_open
                     split_version
                     ) ;
 
-our $VERSION=q{3.1.10};
+our $VERSION=q{3.1.11};
 our $DEBUG;
 
 BEGIN {
@@ -1658,7 +1658,7 @@ Version 3.1
 
 Copyright (C) 2006-2016 Giuseppe Maxia
 
-Home Page  http://github.com/datacharmer
+Home Page  https://github.com/datacharmer
 
 =head1 LEGAL NOTICE
 
