@@ -3,7 +3,7 @@ package MySQL::Sandbox::Recipes;
 use strict;
 use warnings;
 
-our $VERSION=q{3.1.10};
+our $VERSION=q{3.1.11};
 
 1;
 __END__
@@ -677,7 +677,7 @@ Version 3.1
 
 Copyright (C) 2006-2016 Giuseppe Maxia
 
-Home Page  http://github.com/datacharmer
+Home Page  https://github.com/datacharmer
 
 =head1 LEGAL NOTICE
 
