@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION=q{3.1.10};
+our $VERSION=q{3.1.11};
 
 our @MANIFEST = (
 'clear.sh',
@@ -2538,7 +2538,7 @@ Version 3.1
 
 Copyright (C) 2006-2016 Giuseppe Maxia
 
-Home Page  http://github.com/datacharmer
+Home Page  https://github.com/datacharmer
 
 =head1 LEGAL NOTICE
 
